==> fasc-openapi-java-sdk-5.2.6.2-sources.jar: com/fasc/open/api/v5_1/res/template/DocTemplateListInfo.java <==
package com.fasc.open.api.v5_1.res.template;

import com.fasc.open.api.bean.base.BaseBean;

/**
 * @author Fadada
 * 2021/9/11 15:33:01
 */
public class DocTemplateListInfo extends BaseBean {
    private String docTemplateId;
    private String docTemplateName;
    private String docTemplateStatus;
    private String createTime;
    private String updateTime;
    private String catalogName;
    private String createSerialNo;
    private String storageType;

    public String getDocTemplateId() {
        return docTemplateId;
    }

    public void setDocTemplateId(String docTemplateId) {
        this.docTemplateId = docTemplateId;
    }

    public String getDocTemplateName() {
        return docTemplateName;
    }

    public void setDocTemplateName(String docTemplateName) {
        this.docTemplateName = docTemplateName;
    }

    public String getDocTemplateStatus() {
        return docTemplateStatus;
    }

    public void setDocTemplateStatus(String docTemplateStatus) {
        this.docTemplateStatus = docTemplateStatus;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getCatalogName() {
        return catalogName;
    }

    public void setCatalogName(String catalogName) {
        this.catalogName = catalogName;
    }

    public String getCreateSerialNo() {
        return createSerialNo;
    }

    public void setCreateSerialNo(String createSerialNo) {
        this.createSerialNo = createSerialNo;
    }

    public String getStorageType() {
        return storageType;
    }

    public void setStorageType(String storageType) {
        this.storageType = storageType;
    }
}

==> fasc-openapi-java-sdk-5.4.5.0524-sources.jar: com/fasc/open/api/v5_1/res/template/DocTemplateListInfo.java <==
package com.fasc.open.api.v5_1.res.template;

import com.fasc.open.api.bean.base.BaseBean;

/**
 * @author Fadada
 * 2021/9/11 15:33:01
 */
public class DocTemplateListInfo extends BaseBean {
    private String docTemplateId;
    private String docTemplateName;
    private String docTemplateStatus;
    private String createTime;
    private String updateTime;
    private String catalogName;
    private String createSerialNo;
    private String creatorMemberName ;
    private String storageType;

    public String getCreatorMemberName() {
        return creatorMemberName;
    }

    public void setCreatorMemberName(String creatorMemberName) {
        this.creatorMemberName = creatorMemberName;
    }

    public String getDocTemplateId() {
        return docTemplateId;
    }

    public void setDocTemplateId(String docTemplateId) {
        this.docTemplateId = docTemplateId;
    }

    public String getDocTemplateName() {
        return docTemplateName;
    }

    public void setDocTemplateName(String docTemplateName) {
        this.docTemplateName = docTemplateName;
    }

    public String getDocTemplateStatus() {
        return docTemplateStatus;
    }

    public void setDocTemplateStatus(String docTemplateStatus) {
        this.docTemplateStatus = docTemplateStatus;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getCatalogName() {
        return catalogName;
    }

    public void setCatalogName(String catalogName) {
        this.catalogName = catalogName;
    }

    public String getCreateSerialNo() {
        return createSerialNo;
    }

    public void setCreateSerialNo(String createSerialNo) {
        this.createSerialNo = createSerialNo;
    }

    public String getStorageType() {
        return storageType;
    }

    public void setStorageType(String storageType) {
        this.storageType = storageType;
    }
}
